@@ -1,5 +1,9 @@
 """LaminDB setup.
 
+Import the package::
+
+   import lndb_setup as lndb
+
 User API
 --------
 
@@ -46,13 +50,13 @@ Dev API
    Storage
 """
 
-__version__ = "0.26.3"
+__version__ = "0.27.0"
 import atexit
 from os import name as _os_name
 
-from ._info import info
+from ._info import info  # noqa
 from ._schema import schema  # noqa
-from ._set import set_storage
+from ._set import set_storage  # noqa
 from ._settings import settings  # noqa
 from ._settings_instance import InstanceSettings, Storage  # noqa
 from ._settings_user import UserSettings  # noqa
