@@ -29,7 +29,7 @@ def save_settings(
     with open(settings_file, "w") as f:
         for store_key, type in type_hints.items():
             if "__" not in store_key:
-                if store_key in {"dbconfig_", "schema_"}:
+                if store_key in {"dbconfig_", "schema_", "name_"}:
                     settings_key = f"_{store_key.rstrip('_')}"
                 else:
                     settings_key = store_key
