@@ -50,10 +50,10 @@ def register(isettings, usettings):
     # (passing user.name from cloud to the upsert as is done in setup_user.py)
     upsert.user(usettings.email, usettings.id, usettings.handle, usettings.name)
 
-    storage = insert_if_not_exists.storage(
+    storage_db_entry = insert_if_not_exists.storage(
         isettings.storage_root, isettings.storage_region
     )
-    push_instance_if_not_exists(storage)
+    push_instance_if_not_exists(isettings, storage_db_entry)
 
 
 def validate_schema_arg(schema: Optional[str] = None) -> str:
@@ -82,16 +82,20 @@ def persist_check_reload_schema(isettings: InstanceSettings):
         load_schema(isettings, reload=True)
 
 
-def load(instance_name: str, migrate: Optional[bool] = None) -> Optional[str]:
+def load(
+    instance_name: str, owner: Optional[str] = None, migrate: Optional[bool] = None
+) -> Optional[str]:
     """Load existing instance.
 
     Returns `None` if succeeds, otherwise a string error code.
 
     Args:
         instance_name: Instance name.
+        owner: Owner handle.
         migrate: Whether to auto-migrate or not.
     """
-    isettings = load_instance_settings(instance_settings_file(instance_name))
+    owner = owner if owner is not None else settings.user.handle
+    isettings = load_instance_settings(instance_settings_file(instance_name, owner))
     persist_check_reload_schema(isettings)
     logger.info(f"Loading instance: {isettings.name}")
     message = check_migrate(
@@ -154,7 +158,7 @@ def init(
     )
     persist_check_reload_schema(isettings)
     if instance_exists(isettings):
-        return load(isettings.name, migrate=migrate)
+        return load(isettings.name, isettings.owner, migrate=migrate)
     if isettings.cloud_storage and isettings._sqlite_file_local.exists():
         logger.error(ERROR_SQLITE_CACHE.format(settings.instance._sqlite_file_local))
         return None
